@@ -7,8 +7,6 @@
 
 #include "osd.h"
 
-#include "../common/utils.h"
-
 #include <KScreen/Mode>
 
 #include <LayerShellQt/Window>
@@ -44,7 +42,7 @@ void Osd::showActionSelector()
     if (!m_osdActionSelector) {
         m_osdActionSelector = std::make_unique<QQuickView>(&m_engine, nullptr);
         m_osdActionSelector->setInitialProperties({{QLatin1String("actions"), QVariant::fromValue(OsdAction::availableActions())}});
-        m_osdActionSelector->setSource(QStringLiteral("qrc:/qml/OsdSelector.qml"));
+        m_osdActionSelector->setSource(QUrl(QStringLiteral("qrc:/qml/OsdSelector.qml")));
         m_osdActionSelector->setColor(Qt::transparent);
         m_osdActionSelector->setFlag(Qt::FramelessWindowHint);
 
@@ -60,6 +58,7 @@ void Osd::showActionSelector()
 
     if (KWindowSystem::isPlatformWayland()) {
         auto layerWindow = LayerShellQt::Window::get(m_osdActionSelector.get());
+        layerWindow->setScope(QStringLiteral("on-screen-display"));
         layerWindow->setLayer(LayerShellQt::Window::LayerOverlay);
         layerWindow->setAnchors({});
         layerWindow->setDesiredOutput(qGuiApp->screenAt(m_output->pos()));
@@ -69,6 +68,7 @@ void Osd::showActionSelector()
         newGeometry.moveCenter(screen ? screen->geometry().center() : qGuiApp->primaryScreen()->geometry().center());
         m_osdActionSelector->setGeometry(newGeometry);
         KWindowSystem::setState(m_osdActionSelector->winId(), NET::SkipPager | NET::SkipSwitcher | NET::SkipTaskbar);
+        KWindowSystem::setType(m_osdActionSelector->winId(), NET::OnScreenDisplay);
         m_osdActionSelector->requestActivate();
     }
     m_osdActionSelector->setVisible(true);
